from datetime import *
import datetime
from datetime import *
import subprocess
import time
from screeninfo import get_monitors
def view_time():
    view_time = datetime.now().strftime("%H:%M:%S")
    return view_time
def view_date():
    view_date = datetime.now().strftime("%d/%m/%Y")
    return view_date
def sleep(delay):
    if delay == '0' or None:
        sleep = time.sleep(0)
        return sleep
    elif delay:
        sleep1 = time.sleep(delay)
        return sleep1
    else:
        print("Error")
def center_screen(width, height):
    try:
        monitors = get_monitors()
        if monitors:
            monitor = monitors[0]
            screen_width = monitor.width
            screen_height = monitor.height
            sw = (screen_width - width) // 2
            sh = (screen_height - height) // 2
            text = f'{width}x{height}+{sw}+{sh}'
            return text
        else:
            return None
    except Exception as error:
        print('Error: ', error)


# Modules
import requests
import pyautogui
import time
import pandas
import subprocess
import os
from tkinter import messagebox, filedialog, IntVar
import json
import jsonschema
import firebase_admin
from firebase_admin import db, auth, credentials, firestore, app_check, App, datetime


AUTHOR = 'Runkang'
COPYRIGHT = '© Copyright 2023 Informatic365 - SmartSoft - MicroSoftware'

import subprocess
import platform
from customtkinter import *
from tkinter import messagebox
import sys

def turn_off(time):
    '''
    Shutdown pc directly without gui graphics.
    '''
    if time is None or 0:
        subprocess.run(['shutdown', '-s', '-t', '0'])
    else:
        subprocess.run(['shutdown', '-s', '-t', f'{time}'])
def restart(time):
    '''
    Restart pc with or without time
    '''
    if time is None or 0:
        subprocess.run(['shutdown', '-r', '-t', '0'])
    else:
        subprocess.run(['shutdown', '-r', '-t', f'{time}'])
def restart_with_advancedmode(time):
    '''
    Restart pc to advanced mode available on WIndows 10 and 11 or successive version.
    '''
    if time is None or 0:
        subprocess.run(['shutdown', '-r', '-o', '-t', '0'])
    else:
        subprocess.run(['shutdown', '-r', '-o', '-t', f'{time}'])
def turn_off_with_gui():
    '''
    Turn Off pc with gui available on Windows 10 and 11 or successive version.
    '''
    check_windows_version = platform.win32_ver()[0]
    if check_windows_version == '7' or '8':
        shutdowngui = CTk()
        width = 200
        height = 100
        x = (shutdowngui.winfo_screenwidth() - width) // 2
        y = (shutdowngui.winfo_screenheight() - height) // 2
        shutdowngui.geometry(f"{width}x{height}+{x}+{y}")
        shutdowngui.title("Turn Off pc in gui mode")
        shutdown = CTkButton(shutdowngui, text="Turn Off", command=lambda: turn_off(time=0))
        shutdown.place(relx=0.5, rely=0.5, anchor='center')
        shutdowngui.mainloop()
    else:
        subprocess.run(['slidetoshutdown'])
def copyright_view(year, company):
    '''
    Enter the copyright text that will be displayed with the name that you can customize and the year using the attribute 'company' for the name and 'year' for the year.
    Example if i write copyright_view(year='2022 - 2023', company= 'Informatic365')
    then displays "© Copyright 2022 - 2023 Informatic365".
    '''
    get = f'© Copyright {year} {company}'
    return get
def close():
    sys.exit()


from setuptools import *
setup(
    author="Runkang",
    author_email="informatic3650@gmail.com",
    name="pysmart365",
    packages=['pysmart365'],
    version='0.0.6',
    long_description='''This module is to simplify the functions of MicroSoftware and SmartSoft.''',
    description='This module is to simplify the functions of MicroSoftware and SmartSoft.',
    install_requires=[
        'screeninfo',
        'pandas',
        'pyautogui',
        'pytube',
        'pytube3',
        'firebase_admin'
        ],
    url="https://github.com/informatic365/PySmart365/"
)